@@ -2,7 +2,7 @@ from trac.core import *
 from trac.perm import IPermissionPolicy, IPermissionRequestor
 
 revision = "$Rev: 6669 $"
-url = "$URL: https://svn.edgewall.org/repos/trac/tags/trac-0.12.1/sample-plugins/permissions/vulnerability_tickets.py $"
+url = "$URL: file:///var/svn/trac/tags/trac-0.12.4/sample-plugins/permissions/vulnerability_tickets.py $"
 
 class SecurityTicketsPolicy(Component):
     """Prevent public access to security sensitive tickets.
