@@ -5,7 +5,7 @@ from trac.ticket.api import ITicketActionController
 from trac.perm import IPermissionRequestor
 
 revision = "$Rev: 6326 $"
-url = "$URL: https://svn.edgewall.org/repos/trac/tags/trac-0.12.1/sample-plugins/workflow/DeleteTicket.py $"
+url = "$URL: file:///var/svn/trac/tags/trac-0.12.4/sample-plugins/workflow/DeleteTicket.py $"
 
 class DeleteTicketActionController(Component):
     """Provides the admin with a way to delete a ticket.
